/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import {JsonObject} from "@angular/compiler-cli/ngcc/src/packages/entry_point";

@Component({
  selector: 'app-template-cards',
  templateUrl: './template-cards.component.html',
  styleUrls: ['./template-cards.component.scss']
})
export class TemplateCardsComponent implements OnInit {
  @Input() template: any;
  @Output() emitEditEvent = new EventEmitter<JsonObject>();
  public isCollapsedPreview: boolean;
  public isCollapsedDescription: boolean;
  public editorButtonText: string;
  public textToEdit: string;
  public modalTitleText: string;

  constructor() { }

  ngOnInit(): void {
    this.isCollapsedPreview = true
    this.isCollapsedDescription = true
    this.editorButtonText = "Edit " + this.titleify(this.template.name)
    this.modalTitleText = 'Editing "' + this.titleify(this.template.name) + '" template'
  }

  titleify(name: string): string {
    let splitName = name.split('_')
    let titledName = splitName.map((n) => {
      return n[0].toUpperCase() + n.substring(1).toLowerCase()
    })
    if (titledName[titledName.length - 1] != "Email") {
      titledName.push("Email")
    }

    return titledName.join(" ")
  }

  emitEditEventToParent(edits: string) {
    let editDetails = {
      "template_name": this.template.name,
      "template_text": edits
    }
    this.emitEditEvent.emit(editDetails)
  }

}
