# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""screate pims split email template

Revision ID: 40bd8bd55556
Revises: 30d66371f949
Create Date: 2023-03-29 08:13:59.120574

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "40bd8bd55556"
down_revision = "30d66371f949"
branch_labels = None
depends_on = None

pims_template = """
Subject: PIMS Split Workflow Finished

Dear DA,

{{status}}

Calibration: {{calibration}}
CASA from: {{casa_path}}
Restore path: {{restore_path}}
Lustre processing area: {{lustre_dir}}
Cache directory: {{cache_dir}}

{{#num_products.length}}
SE Coarse Cube and Continuum images per tile in the database:
{{#num_products}}
Tile: {{tile_name}}, CC: {{num_coarse_cube}}, SE: {{num_continuum}}
{{/num_products}}
{{/num_products.length}}

Failed Splits/Total Splits: {{num_failed_splits}}/{{num_splits}}
{{#failed_splits.length}}
Failed splits:
{{#failed_splits}}
{{.}}
{{/failed_splits}}
{{/failed_splits.length}}

Best regards,
NRAO Workspaces
"""

pims_description = "Email template for notifying the VLASS analysts on the status of their PIMS split jobs"


def upgrade():
    op.execute(
        f"""
        INSERT INTO notification_templates (name, description, template)
        VALUES ('pims_notification', E'{pims_description}', E'{pims_template}')
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM notification_templates WHERE name='pims_notification'
        """
    )
